# Changelog

## [0.0.1] - 2020-05-29

## Added
- Forward and inverse spin-weighted spherical harmonic transforms.
- Support for MW sampling and arbitrary grid samplings.
- Support for isolatitude sampling with evenly-spaced latitudes.
- Evaluation of spin-weighted spherical harmonic functions and wigner-d functions.
- Memory-conscious caching of intermediate values.
